from dataclasses import dataclass
from uuid import UUID

from inferscope import Client, DataDescription
from inferscope.models import ArtifactPack, StoredArtifact


@dataclass
class StoredArtifactHelper:
    _client: Client
    _pack_uid: UUID
    _parent_project_uid: UUID
    _artifact_package: ArtifactPack | None = None

    def __init__(self, client: Client, parent_project_uid: UUID):
        self._client = client
        self._parent_project_uid = parent_project_uid
        self._pack_uid = client.create_artifact_package(self._parent_project_uid)
        self._artifact_package = None

    def upload_artifact(
        self,
        path: str,
        blob: bytes | None = None,
        local_path: str | None = None,
        data_description: DataDescription | None = None,
    ) -> StoredArtifact:
        assert bool(blob) != bool(local_path), "Exactly one parameter: blob or local_path can be specified"
        if local_path:
            blob = open(local_path, 'rb').read()
        return self._client.upload_file_to_artifact_pack(
            parent_project_id=self._parent_project_uid,
            artifact_pack_id=self._pack_uid,
            path=path,
            blob=blob,
            data_description=data_description
        )

    @property
    def pack_uid(self) -> UUID:
        return self._pack_uid
